==> librepcb-2.0.0-source.zip: librepcb-2.0.0/AUTHORS.md <==
# Authors

Many people have contributed to LibrePCB. This is an attempt to list them all.

If you are a contributor and your name is not listed here, feel free to add
yourself by creating a pull request (see [CONTRIBUTING.md](CONTRIBUTING.md)).

## Main Authors
- U. Bruhin ([@ubruhin](https://github.com/ubruhin))

## Contributors
- Danilo Bargen ([@dbrgn](https://github.com/dbrgn))
- Raphael Nestler ([@rnestler](https://github.com/rnestler))
- Lucas ([@5n8ke](https://github.com/5n8ke))
- Frantisek Burian ([@BuFran](https://github.com/BuFran))
- Eduardo Sánchez Muñoz ([@eduardosm](https://github.com/eduardosm))
- [@Luz](https://github.com/Luz)
- Roman V ([@NZSmartie](https://github.com/NZSmartie))
- [@kliment](https://github.com/kliment)
- [@0xB767B](https://github.com/0xB767B)
- Federico Ceratto ([@FedericoCeratto](https://github.com/FedericoCeratto))
- Jeff Wheeler ([@jeffwheeler](https://github.com/jeffwheeler))
- [@luzpaz](https://github.com/luzpaz)
- Javier Sánchez Parra ([@javsanpar](https://github.com/javsanpar))
- [@bjaminn](https://github.com/bjaminn)
- Tubbles ([@Tubbles](https://github.com/Tubbles))
- Troy Denton ([@trdenton](https://github.com/trdenton))
- [@melak](https://github.com/melak)
- Rob Weber ([@robbawebba](https://github.com/robbawebba))
- Răzvan Cojocaru ([@rzvncj](https://github.com/rzvncj))
- [@NiFa18](https://github.com/NiFa18)
- [@The-Compiler](https://github.com/The-Compiler)
- Christian Gwerder ([@chrisgwerder](https://github.com/chrisgwerder))
- yuri@FreeBSD ([@yurivict](https://github.com/yurivict))
- [@web-coder-of-rpi](https://github.com/web-coder-of-rpi)
- [@probonopd](https://github.com/probonopd)
- [@picknick-](https://github.com/picknick-)
- [@mi4code](https://github.com/mi4code)
- [@hephaisto](https://github.com/hephaisto)
- [@freddii](https://github.com/freddii)
- Tobias Backer Dirks ([@omgitsaheadcrab](https://github.com/omgitsaheadcrab))
- Thomas Fischl ([@EmbedME](https://github.com/EmbedME))
- Raphael Theiler ([@ammoniak](https://github.com/ammoniak))
- Petros S ([@Petross404](https://github.com/Petross404))
- Nao Pross ([@NaoPross](https://github.com/NaoPross))
- [@mexchip](https://github.com/mexchip)
- Josua Schmid ([@schmijos](https://github.com/schmijos))
- Ilia Sharin ([@alfishe](https://github.com/alfishe))
- Fred Turkington ([@z3ugma](https://github.com/z3ugma))
- David Lamparter ([@eqvinox](https://github.com/eqvinox))
- Connor Slade ([@connorslade](https://github.com/connorslade))
- Allan Nordhøy ([@comradekingu](https://github.com/comradekingu))
- Alexander Wilms

==> librepcb-2.0.1-source.zip: librepcb-2.0.1/AUTHORS.md <==
# Authors

Many people have contributed to LibrePCB. This is an attempt to list them all.

If you are a contributor and your name is not listed here, feel free to add
yourself by creating a pull request (see [CONTRIBUTING.md](CONTRIBUTING.md)).

## Main Authors
- U. Bruhin ([@ubruhin](https://github.com/ubruhin))

## Contributors
- Danilo Bargen ([@dbrgn](https://github.com/dbrgn))
- Raphael Nestler ([@rnestler](https://github.com/rnestler))
- Lucas ([@5n8ke](https://github.com/5n8ke))
- Frantisek Burian ([@BuFran](https://github.com/BuFran))
- Eduardo Sánchez Muñoz ([@eduardosm](https://github.com/eduardosm))
- [@Luz](https://github.com/Luz)
- Roman V ([@NZSmartie](https://github.com/NZSmartie))
- [@kliment](https://github.com/kliment)
- [@0xB767B](https://github.com/0xB767B)
- Federico Ceratto ([@FedericoCeratto](https://github.com/FedericoCeratto))
- Jeff Wheeler ([@jeffwheeler](https://github.com/jeffwheeler))
- Javier Sánchez Parra ([@javsanpar](https://github.com/javsanpar))
- [@luzpaz](https://github.com/luzpaz)
- [@bjaminn](https://github.com/bjaminn)
- Tubbles ([@Tubbles](https://github.com/Tubbles))
- Troy Denton ([@trdenton](https://github.com/trdenton))
- [@melak](https://github.com/melak)
- Rob Weber ([@robbawebba](https://github.com/robbawebba))
- Răzvan Cojocaru ([@rzvncj](https://github.com/rzvncj))
- [@NiFa18](https://github.com/NiFa18)
- Freya Bruhin ([@The-Compiler](https://github.com/The-Compiler))
- Christian Gwerder ([@chrisgwerder](https://github.com/chrisgwerder))
- yuri@FreeBSD ([@yurivict](https://github.com/yurivict))
- [@web-coder-of-rpi](https://github.com/web-coder-of-rpi)
- [@probonopd](https://github.com/probonopd)
- [@picknick-](https://github.com/picknick-)
- [@mi4code](https://github.com/mi4code)
- [@hephaisto](https://github.com/hephaisto)
- [@freddii](https://github.com/freddii)
- Tobias Backer Dirks ([@omgitsaheadcrab](https://github.com/omgitsaheadcrab))
- Thomas Fischl ([@EmbedME](https://github.com/EmbedME))
- Raphael Theiler ([@ammoniak](https://github.com/ammoniak))
- Petros S ([@Petross404](https://github.com/Petross404))
- Nao Pross ([@NaoPross](https://github.com/NaoPross))
- [@mexchip](https://github.com/mexchip)
- Josua Schmid ([@schmijos](https://github.com/schmijos))
- Ilia Sharin ([@alfishe](https://github.com/alfishe))
- Fred Turkington ([@z3ugma](https://github.com/z3ugma))
- David Lamparter ([@eqvinox](https://github.com/eqvinox))
- Connor Slade ([@connorslade](https://github.com/connorslade))
- Brayden Chan ([@megabyte6](https://github.com/megabyte6))
- Allan Nordhøy ([@comradekingu](https://github.com/comradekingu))
- Alexander Wilms
